@@ -5,7 +5,7 @@ package HTTP::AnyUA::Backend::AnyEvent::HTTP;
 use warnings;
 use strict;
 
-our $VERSION = '0.903'; # VERSION
+our $VERSION = '0.904'; # VERSION
 
 use parent 'HTTP::AnyUA::Backend';
 
@@ -13,6 +13,14 @@ use Future;
 use HTTP::AnyUA::Util;
 
 
+my $future_class;
+BEGIN {
+    $future_class = 'Future';
+    eval 'use AnyEvent::Future';    ## no critic
+    $future_class = 'AnyEvent::Future' if !$@;
+}
+
+
 
 sub options { @_ == 2 ? $_[0]->{options} = pop : $_[0]->{options} }
 
@@ -23,7 +31,7 @@ sub request {
     my ($method, $url, $args) = @_;
 
     my %opts    = $self->_munge_request($method, $url, $args);
-    my $future  = Future->new;
+    my $future  = $future_class->new;
 
     require AnyEvent::HTTP;
     AnyEvent::HTTP::http_request($method => $url, %opts, sub {
@@ -139,13 +147,16 @@ HTTP::AnyUA::Backend::AnyEvent::HTTP - A unified programming interface for AnyEv
 
 =head1 VERSION
 
-version 0.903
+version 0.904
 
 =head1 DESCRIPTION
 
 This module adds support for the HTTP client L<AnyEvent::HTTP> to be used with the unified
 programming interface provided by L<HTTP::AnyUA>.
 
+If installed, requests will return L<AnyEvent::Future> rather than L<Future>. This allows the use of
+the C<< ->get >> method to await a result.
+
 =head1 METHODS
 
 =head2 options
@@ -179,7 +190,7 @@ Charles McGarvey <chazmcgarvey@brokenzipper.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Charles McGarvey.
+This software is copyright (c) 2019 by Charles McGarvey.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
